@@ -6,11 +6,11 @@ from autoastro.profiles import (
     light_and_mass_profiles as lmp,
 )
 from autoastro.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
-from autoastro.galaxy.galaxy_data import GalaxyData as galaxy_data
-from autoastro.galaxy.masked_galaxy_data import MaskedGalaxyData as masked_galaxy_data
-from autoastro.galaxy.fit_galaxy import GalaxyFit as fit_galaxy
+from autoastro.galaxy.galaxy_data import GalaxyData
+from autoastro.galaxy.masked_galaxy_data import MaskedGalaxyDataset
+from autoastro.galaxy.fit_galaxy import FitGalaxy
 from autoastro.galaxy.galaxy_model import GalaxyModel
 from autoastro.hyper import hyper_data
 from autoastro import plot
 
-__version__ = '0.5.2'
+__version__ = '0.6.0'
